@@ -19,7 +19,7 @@ def request(method, url, params=None, data=None, headers=None, cookies=None,
             files=None, timeout=None, allow_redirects=False, max_redirects=5, proxy=None,
             auth=None, network_interface=None, use_gzip=None, validate_cert=False,
             ca_certs=None, cert=None, debug=False, user_agent=None, ip_v6=False,
-            hooks=None, options=None, callback=None, return_response=True, **kwargs):
+            hooks=None, options=None, callback=None, return_response=True, encode_query=True, **kwargs):
     """Construct and sends a Request object. Returns :class `Response`.
 
     Arguments:
@@ -65,7 +65,7 @@ def request(method, url, params=None, data=None, headers=None, cookies=None,
         files=files, timeout=timeout, allow_redirects=allow_redirects, max_redirects=max_redirects, proxy=proxy,
         auth=auth, network_interface=network_interface, use_gzip=use_gzip, validate_cert=validate_cert,
         ca_certs=ca_certs, cert=cert, debug=debug, user_agent=user_agent, ip_v6=ip_v6, options=options,
-        callback=callback, **kwargs)
+        callback=callback, encode_query=encode_query, **kwargs)
 
     # TODO: add hooks
     r = Request(**args)
